@@ -10,9 +10,10 @@
 """
 
 import re
-from .constants import ENGLISH_STOP_WORDS, ENGLISH_10K_WORDS #, LANGUAGE_MODEL
+from .constants import STOP_WORDS, ENGLISH_WORDS
 from nektar import Waggle
 
+KNOWN_WORDS = STOP_WORDS+ENGLISH_WORDS
 
 class Scrutineer:
     def __init__(
@@ -96,12 +97,101 @@ class Scrutineer:
         self.analysis["score"] = score
         return self.analysis
 
+"""
+class Analytics:
+    def __init__(self, author, limit=100, retries=1):
+        self._author = str(author)[:16]
+        self._limit = max(min(int(limit), 100), 1)
+        self._retries = max(min(int(retries), 5), 1)
+        self.analysis = {}
+    
+    def analyze(self):
+        tags = {}
+        votes = {}
+        post_payouts = []
+        post_engagements = []
+        
+        hive = Waggle(self._author)
+        for blog in hive.blogs(limit=self._limit):
+
+            dt = blog["created"][:10]
+            self.analysis[dt] = {}
+            
+            payout = blog["payout"]
+            
+            # growth[dt]["post"] = blog["title"]
+            self.analysis[dt]["payout"] = payout
+            self.analysis[dt]["engagements"] = blog["children"]
+            self.analysis[dt]["votes"] = len(blog["active_votes"])
+            self.analysis[dt]["score"] = scoring(blog)
+            
+            for vote in blog["active_votes"]:
+                voter = vote["voter"]
+                votes[voter] = votes.get(voter, []) + [vote["rshares"]]
+            
+            if "tags" not in blog["json_metadata"]:
+                continue
+            for tag in blog["json_metadata"]["tags"]:
+                tags[tag] = tags.get(tag, []) + [payout]
+                
+            post_payouts.append([payout, blog["title"]])
+            post_engagements.append([blog["children"], blog["title"] + " @" + self._author + "/" + blog["permlink"]])
+        
+        self.analysis.save()
+        
+        consistent = []
+        high_value = []
+        for voter, rshares in votes.items():
+            consistent.append([len(rshares), voter])
+            high_value.append([sorted(rshares)[-1], voter])
+
+        consistent = list(reversed(sorted(consistent)))
+        consistent = [x[1]+"-"+str(x[0]) for x in consistent][:100]
+        
+        high_value = list(reversed(sorted(high_value)))
+        high_value = [x[1] for x in high_value][:100]
+        
+        high_value_tags = []
+        for tag, payouts in tags.items():
+            high_value_tags.append([sorted(payouts)[-1], tag])
+        
+        high_value_tags = list(reversed(sorted(high_value_tags)))
+        high_value_tags = [x[1]+str(x[0]) for x in high_value_tags][:10]
+        
+        post_payouts = list(reversed(sorted(post_payouts)))
+        post_payouts = [x[1] for x in post_payouts][:5]
+        
+        post_engagements = list(reversed(sorted(post_engagements)))
+        post_engagements = [x[1] for x in post_engagements][:5]
+
+        
+        colors = ("red", "green", "blue", "yellow")
+        dates = list(reversed(list(self.analysis.keys())))
+        properties = [ x for x in list(self.analysis[dates[0]].keys()) if x != "post" ]
+        for i in range(len(properties)):
+            values = []
+            name = properties[i]
+            for j in range(len(dates)):
+                adjusted = self.analysis[dates[j]][name]
+                if properties[i] == "Upvotes":
+                    adjusted /= 10
+                values.append(adjusted)
+            # plt.plot(list(range(len(dates))), values, color=colors[i], label=name)
+          
+        # plt.xlabel("Date")
+        # plt.ylabel("Properties")
+        # plt.title("Hive Content Performance")
+        
+        # plt.legend()
+        # plt.show()
+"""
 
 def _analyze_title(title, keywords=None):
     analysis = {}
+    analysis["title"] = title
     length = len(title.encode("utf-8"))
     
-    analysis["below_min"] = length < 30
+    analysis["below_min"] = length < 20
     analysis["above_max"] = length > 60
 
     analysis["seo_keywords"] = 0
@@ -115,7 +205,7 @@ def _analyze_title(title, keywords=None):
         analysis["seo_keywords"] = analysis["readability"]
 
     analysis["score"] = int(not (analysis["below_min"] or analysis["above_max"])) * (
-        ((analysis["readability"] * 2) + analysis["seo_keywords"]) / 3
+        ((analysis["readability"] * 9) + analysis["seo_keywords"]) / 10
     )
     return analysis
 
@@ -125,8 +215,10 @@ def _parse_body(body):
     pattern = (
         r"!\[[\w\"\-\.~!#$%&'()*+,;=:@\/?\ ]*\]\([\w\"\-\.~!#$%&'()*+,;=:@\/?\ ]+\)"
     )
-    cleaned = re.sub(pattern, "", body)
-    cleaned = cleaned.replace("\n", " ")
+    cleaned = re.sub(pattern, "", body).lower()
+    cleaned = re.sub(r"[\n\.]", " ", cleaned)
+    cleaned = re.sub(r"\u2013", " ", cleaned)
+    cleaned = re.sub(r"\u2014", " ", cleaned)
 
     ## remove other formatting codes
     ## do not change order of patterns !!
@@ -145,54 +237,33 @@ def _parse_body(body):
         r"--[\-]+",  # blocks, horizontal rule
         r"[\(\[\{\}\]\)]",  # trailing parentheses, brackets, and braces
         r"@[a-z0-9\-\.]{3,16}",  # user tags
-        r"[^\w\s]",
     ]  
     for pattern in patterns:
         cleaned = re.sub(pattern, "", cleaned)
     cleaned = re.sub(r"[\s]+", " ", cleaned)
 
     ## strip non-ascii characters
-    stripped = re.sub(r"[^\ -~]", "", cleaned)
+    stripped = re.sub(r"[^'\w\-\s]", "", cleaned)
+    stripped = re.sub(r"[^\ -~]", "", stripped)
     return cleaned, stripped
 
 def _analyze_body(cleaned, stripped, deep):
     analysis = {}
-    analysis["cleaned"] = len(cleaned.split(" "))
-    analysis["stripped"] = len(stripped.split(" "))
+    analysis["cleaned"] = len([1 for x in cleaned.split(" ") if x.strip()])
+    analysis["stripped"] = len([1 for x in stripped.split(" ") if x.strip()])
+    
+    corpus = stripped.split(" ")
+    analysis["english"] = len([x for x in corpus if x in KNOWN_WORDS])
+    
     analysis["seo_keywords"] = _get_bigrams(stripped)
 
-    """
-    
-    analysis["languages"] = {}
-    if deep:
-        guesses = []
-        chunks = list(re.findall(r".{50}", stripped))
-        normalized = [_normalize(x.ljust(50, " ")) for x in chunks]
-        for chunk in normalized:
-            languages = []
-            for lang, weights in LANGUAGE_MODEL.items():
-                likelihood = _resultant(chunk, weights)
-                languages.append([likelihood, lang])
-            guess = list(reversed(sorted(languages)))[0][1]
-            guesses.append(guess)
-        lines = len(guesses)
-        for lang in set(guesses):
-            analysis["languages"][lang] = guesses.count(lang) / lines
-    """
-
-    words = list(re.findall(r"\b\w\w+\b", stripped.lower()))
-    words = len([x for x in words if x not in ENGLISH_10K_WORDS])
-    if words > 50:
-        analysis["stripped"] -= words
-        analysis["cleaned"] -= words
-
-    analysis["above_499"] = analysis["stripped"] > 499
-    analysis["above_999"] = analysis["stripped"] > 999
+    analysis["above_400"] = analysis["stripped"] > 400
+    analysis["above_800"] = analysis["stripped"] > 800
 
     analysis["score"] = (
-        (analysis["stripped"] / analysis["cleaned"])
-        + analysis["above_499"]
-        + analysis["above_999"]
+        (analysis["english"] / analysis["cleaned"])
+        + analysis["above_400"]
+        + analysis["above_800"]
     ) / 3
     return analysis
 
@@ -203,7 +274,7 @@ def _get_bigrams(contents, occurrence=4, limit=5):
 
     bigrams = {}
     words = list(re.findall(r"\b\w\w+\b", contents.lower()))
-    words = [x for x in words if x not in ENGLISH_STOP_WORDS]
+    words = [x for x in words if x not in STOP_WORDS]
     for i in range(len(words) - 2):
         bigram = " ".join(words[i : i + 2])
         bigrams[bigram] = bigrams.get(bigram, 0) + 1
@@ -250,21 +321,4 @@ def _analyze_tags(tags, max_tags):
         analysis["score"] = 1
         if analysis["count"] > max_tags:
             analysis["score"] = 1 / (analysis["count"] - 5)
-    return analysis
-
-def _normalize(pattern, value=None):
-    mx = 1114111
-    pattern = [(ord(item)/mx) for item in pattern]
-    if value is not None:
-        return pattern + [value]
-    return pattern
-
-def _resultant(x, w):
-    """
-        x: inputs
-        w: weights
-    """
-    v = x[0] * w[0]
-    for i in range(1, len(x)):
-        v += x[i] * w[i]
-    return (v + w[-1])
\ No newline at end of file
+    return analysis
\ No newline at end of file
